@@ -1,20 +1,20 @@
 ;;; connection.scm: talk to dict buddy
-;;; author: Anand Avati <avati@zresearch.com>
-;;; copyright 2005 FreeTalk Core Team
-
-;;; This program is free software; you can redistribute it and/or
-;;; modify it under the terms of the GNU General Public License as
-;;; published by the Free Software Foundation; either version 2, or (at
-;;; your option) any later version.
+;;; Copyright (c) 2005, 2006, 2007 Freetalk Core Team 
+;;; This file is part of GNU Freetalk.
 ;;; 
-;;; This program is distributed in the hope that it will be useful, but
+;;; Freetalk is free software; you can redistribute it and/or modify it
+;;; under the terms of the GNU General Public License as published by
+;;; the Free Software Foundation; either version 3 of the License, or
+;;; (at your option) any later version.
+;;; 
+;;; Freetalk is distributed in the hope that it will be useful, but
 ;;; WITHOUT ANY WARRANTY; without even the implied warranty of
 ;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 ;;; General Public License for more details.
 ;;; 
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program; if not, write to the Free Software
-;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA
+;;; along with this program.  If not, see
+;;; <http://www.gnu.org/licenses/>.
 
 (use-modules (ice-9 string-fun))
 
@@ -24,6 +24,7 @@
 	((= ret -1) (ft-display (_ "Server not set")))
 	((= ret -2) (ft-display (_ "JID not set")))
 	((= ret -3) (ft-display (_ "SSL support not available")))
+	((= ret -5) (ft-display (_ "Proxy Server not set")))
 	(else (ft-display (string-append (_ "Error, could not connect : ")
                                      (number->string ret))))))
 
@@ -66,7 +67,7 @@
   (display (string-append (_ "Enable TLS/SSL (Y/N)? [Y]: ")))
   (let ((ans (read-line-clean)))
     (ft-set-sslconn! (if (or (string=? ans "n")
-			      (string=? ans "N"))
+			     (string=? ans "N"))
 			 #f
 			 #t))))
 
@@ -86,6 +87,33 @@
 		       (read-num-clean)
 		       "0")))
 
+(define (read-proxy)
+  (display (string-append (_ "Enable Proxy (Y/N)? [Y]: ")))
+  (let ((ans (read-line-clean)))
+    (ft-set-proxy! (if (or (string=? ans "n")
+			   (string=? ans "N"))
+		       #f
+		       #t))))
+
+(define (read-proxyserver)
+  (display (string-append (_ "ProxyServer: ")))
+  (set-if-not-empty! ft-set-proxyserver! (read-line-clean) (ft-get-proxyserver)))
+
+(define (read-proxyport)
+  (let ((proxyport 8080))
+    (display (string-append (_ "ProxyPort [") (number->string proxyport) "]: "))
+    (set-if-not-empty! (lambda (str-num)
+			 (ft-set-proxyport! (string->number str-num)))
+		       (read-num-clean)
+		       "8080")))
+
+(define (read-proxyuname)
+  (display (string-append (_ "ProxyUsername: ")))
+  (set-if-not-empty! ft-set-proxyuname! (read-line-clean) (ft-get-proxyuname)))
+
+(define (read-proxypasswd)
+  (set-if-not-empty! ft-set-proxypasswd! (getpass "ProxyPassword: ") ""))
+
 (define (/connect args)
   (connect-handle (ft-connect)))
 (add-command! /connect "/connect" "/connect" "connect to jabber server - non blocking")
@@ -101,6 +129,14 @@
     (read-server)
     (read-sslconn)
     (read-port)
+    (read-proxy)
+    (if (ft-get-proxy?)
+	(begin
+	  (read-proxyserver)
+	  (read-proxyport)
+	  (read-proxyuname)
+	  (read-proxypasswd)
+	""))
     (connect-handle (ft-connect))))
 (add-command! /login "/login" "/login" "Interactive login to jabber server - blocking")
 
