@@ -1,21 +1,20 @@
 /*
-  Author: Anand Avati <avati@zresearch.com>
-  (C) 2005,2006 Freetalk core team
+  Copyright (c) 2005, 2006, 2007 Freetalk Core Team
+  This file is part of GNU Freetalk.
   
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License, or (at your option) any later version.
-    
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-    
-  You should have received a copy of the GNU General Public
-  License along with this program; if not, write to the Free
-  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301 USA
+  Freetalk is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published
+  by the Free Software Foundation; either version 3 of the License,
+  or (at your option) any later version.
+  
+  Freetalk is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+  
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see
+  <http://www.gnu.org/licenses/>.
 */
 
 #ifndef __COMMANDS_H__
@@ -31,12 +30,22 @@ int do_set_server (const char *server);
 const char * do_get_server (void);
 int do_set_port (unsigned short int port);
 int do_get_port (void);
+int do_set_proxyserver (const char *proxyserver);
+const char * do_get_proxyserver (void);
+int do_set_proxyuname (const char *proxyuname);
+int do_set_proxypasswd (const char *proxypasswd);
+const char * do_get_proxyuname (void);
+const char * do_get_proxypasswd (void);
+int do_set_proxyport (unsigned short int proxyport);
+int do_get_proxyport (void);
 int do_set_password (const char *password);
 const char * do_get_password (void);
 int do_set_prompt (const char *prompt);
 const char * do_get_prompt (void);
 int do_set_ssl (char value);
 int do_get_ssl (void);
+int do_set_proxy (char value);
+int do_get_proxy (void);
 int do_send_message (char *jid, char *msg);
 int do_send_message_no_hook (char *jid, char *msg);
 int do_set_daemon (void); /* switch to daemon mode */
