@@ -1,20 +1,20 @@
 /*
-  (C) 2005,2006 Freetalk core team <http://www.gnu.org/software/freetalk/>
-  
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License, or (at your option) any later version.
-    
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-    
-  You should have received a copy of the GNU General Public
-  License along with this program; if not, write to the Free
-  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301 USA
+  Copyright (c) 2005, 2006, 2007 Freetalk Core Team 
+  This file is part of GNU Freetalk.
+
+  Freetalk is free software; you can redistribute it and/or modify it
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 3 of the License, or
+  (at your option) any later version.
+
+  Freetalk is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see
+  <http://www.gnu.org/licenses/>.
 */
 
 #include <stdio.h>
@@ -61,6 +61,7 @@ state_init (void)
   state.config_dir = (char *)calloc (1, strlen (getenv ("HOME")) + 1 + strlen (".freetalk") + 1);
   sprintf (state.config_dir, "%s/.freetalk", getenv ("HOME"));
   state.need_ssl = 1; /* turn on ssl by default */
+  state.need_proxy = 0; /* turn off proxy by default */
   state.f_state = NULL;
   state.download_dirname = (char *)calloc (1, strlen (getenv ("HOME")) + 1 + strlen (".freetalk/downloads") + 1);
   sprintf (state.download_dirname, "%s/.freetalk/downloads", getenv ("HOME"));
