@@ -1,26 +1,24 @@
 /*
-   Author: Anand Avati <avati@zresearch.com>
-   (C) 2005 FreeTalk Core Team
-   
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License, or (at your option) any later version.
-    
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-   GNU General Public License for more details.
-    
-   You should have received a copy of the GNU General Public
-   License along with this program; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301 USA
-
-   NOTE -
-   This is the readline interpreter
-   This file is the interface between readline and commands.c (do_*)
+  Copyright (c) 2005, 2006, 2007 Freetalk Core Team
+  This file is part of Freetalk.
+  
+  Freetalk is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published
+  by the Free Software Foundation; either version 3 of the License,
+  or (at your option) any later version.
+  
+  Freetalk is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+  
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see
+  <http://www.gnu.org/licenses/>.
 
+  NOTE -
+  This is the readline interpreter
+  This file is the interface between readline and commands.c (do_*)
 */
 
 #include <stdio.h>
@@ -35,6 +33,7 @@
 #include "freetalk.h"
 #include "commands.h"
 #include "roster.h"
+#include "compat.h"
 
 GSList *dict_words = NULL;
 
