@@ -1,21 +1,20 @@
 /*
-  Author: Anand Avati <avati@zresearch.com>
-  (C) 2005,2006 Freetalk core team
+  Copyright (c) 2005, 2006, 2007 Freetalk Core Team
+  This file is part of Freetalk.
   
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License as
-  published by the Free Software Foundation; either version 2 of
-  the License, or (at your option) any later version.
-    
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-    
-  You should have received a copy of the GNU General Public
-  License along with this program; if not, write to the Free
-  Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301 USA
+  Freetalk is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published
+  by the Free Software Foundation; either version 3 of the License,
+  or (at your option) any later version.
+  
+  Freetalk is distributed in the hope that it will be useful, but
+  WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  General Public License for more details.
+  
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see
+  <http://www.gnu.org/licenses/>.
 */
 
 #ifndef __PRIMITIVES_H__
@@ -31,6 +30,18 @@ SCM ex_set_jid (SCM scm_jid);
 SCM ex_get_server (void);
 SCM ex_set_server (SCM scm_server);
 
+SCM ex_get_proxyserver (void);
+SCM ex_set_proxyserver (SCM scm_proxyserver);
+
+SCM ex_get_proxy (void);
+SCM ex_set_proxy (SCM scm_proxy);
+
+SCM ex_get_proxyuname (void);
+SCM ex_set_proxyuname (SCM scm_proxyuname);
+
+SCM ex_get_proxypasswd (void);
+SCM ex_set_proxypasswd (SCM scm_proxypasswd);
+
 SCM ex_get_password (void);
 SCM ex_set_password (SCM scm_password);
 
@@ -52,6 +63,9 @@ SCM ex_get_prompt (void);
 SCM ex_get_port (void);
 SCM ex_set_port (SCM scm_port);
 
+SCM ex_get_proxyport (void);
+SCM ex_set_proxyport (SCM scm_proxyport);
+
 SCM ex_display (SCM scm_line);
 
 SCM ex_get_conn_status (void);
